aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/styles/prosilver/template/ajax.js
diff options
context:
space:
mode:
authorMarc Alexander <admin@m-a-styles.de>2016-11-12 19:41:10 +0100
committerMarc Alexander <admin@m-a-styles.de>2016-11-12 19:41:10 +0100
commit9c7e8c2dc5607a594f1e8d3a633dc686e8c002a7 (patch)
tree3d0676a91b26bb4fabdefe52836d60aa65071489 /phpBB/styles/prosilver/template/ajax.js
parent2319748c08539301242e5c5c713c3841b8067e6d (diff)
parent372324cead4f9068ebe3ca10c85858af833a8026 (diff)
downloadforums-9c7e8c2dc5607a594f1e8d3a633dc686e8c002a7.tar
forums-9c7e8c2dc5607a594f1e8d3a633dc686e8c002a7.tar.gz
forums-9c7e8c2dc5607a594f1e8d3a633dc686e8c002a7.tar.bz2
forums-9c7e8c2dc5607a594f1e8d3a633dc686e8c002a7.tar.xz
forums-9c7e8c2dc5607a594f1e8d3a633dc686e8c002a7.zip
Merge branch '3.1.x' into 3.2.x
Diffstat (limited to 'phpBB/styles/prosilver/template/ajax.js')
-rw-r--r--phpBB/styles/prosilver/template/ajax.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/phpBB/styles/prosilver/template/ajax.js b/phpBB/styles/prosilver/template/ajax.js
index aec6b0bbe6..3888d26785 100644
--- a/phpBB/styles/prosilver/template/ajax.js
+++ b/phpBB/styles/prosilver/template/ajax.js
@@ -132,9 +132,9 @@ phpbb.markNotifications = function($popup, unreadCount) {
// Update the unread count.
$('strong', '#notification_list_button').html(unreadCount);
// Remove the Mark all read link if there are no unread notifications.
if (!unreadCount) {
- $('#mark_all_notifications').remove();
+ $('#mark_all_notifications, #notification_list_button > strong').remove();
}
// Update page title
@@ -132,9 +132,9 @@ phpbb.markNotifications = function($popup, unreadCount) {
// Update the unread count.
$('strong', '#notification_list_button').html(unreadCount);
- // Remove the Mark all read link if there are no unread notifications.
+ // Remove the Mark all read link & notification count if there are no unread notifications.
if (!unreadCount) {